<?php

/**
 * Add featured image as background image.
 */
if ( ! function_exists( 'arcegator_background_image' ) ) {
	function arcegator_background_image() {

		if ( 'post' === get_post_type() ) {
			$image = arcegator_get_attachment_image_src( get_the_ID(), get_post_thumbnail_id( get_the_ID() ), 'post-thumbnail' );
		}
		else {
			$image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'post-thumbnail' );
			$image = $image[0];
		}

		if ( ! $image ) {
			return;
		}

		printf( ' style="background-image: url(\'%s\');"', esc_url( $image ) );
	}
}

/**
 * Add featured image as background image.
 */
if ( ! function_exists( 'arcegator_hero_background_image' ) ) {
	function arcegator_hero_background_image() {

		if ( 'post' === get_post_type() ) {
			$image = arcegator_get_attachment_image_src( get_the_ID(), get_post_thumbnail_id( get_the_ID() ), 'full' );
		}
		else {
			$image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
			$image = $image[0];
		}

		if ( ! $image ) {
			return;
		}

		printf( ' style="background-image: url(\'%s\');"', esc_url( $image ) );
	}
}


/**
 * Add color class to curve down footer.
 */
if ( ! function_exists( 'arcegator_curve_down_footer_color_class' ) ) {
	function arcegator_curve_down_footer_color_class() {

		if ( is_active_sidebar( 'sidebar-2' ) && !is_active_sidebar( 'sidebar-3' ) ) {
			$color_class = ' sidebar-footer-2-color';
		}else if ( is_active_sidebar( 'sidebar-3' ) ) {
			$color_class = ' sidebar-footer-3-color';
		}else {
			return;
		}
		echo esc_html($color_class);
	}
}

/**
 * Add featured image as background image.
 */
if ( ! function_exists( 'arcegator_hero_class' ) ) {
	function arcegator_hero_class() {
		if ( 'post' !== get_post_type() && ! has_post_thumbnail() || 'post' === get_post_type() && ! arcegator_has_post_thumbnail() ) {
			$return_class = 'no-thumbnail';
		}else{
			$return_class = 'with-thumbnail';
		}
		echo esc_html($return_class);
	}
}

if ( ! function_exists( 'arcegator_entry_footer' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time, tags and comments.
	 */
	function arcegator_entry_footer() {
		if ( 'post' === get_post_type() ) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
			}

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
			);

			$posted_on = sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>', esc_url( get_permalink() ), $time_string );

			if ( is_sticky() && ! is_single() ) {
				$posted_on = sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>', esc_url( get_permalink() ), esc_html__( 'Featured Post', 'arcegator' ) );
			}

			// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			echo '<span class="posted-on">' . $posted_on . '</span>';

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'arcegator' ) );
			if ( $tags_list && ! is_wp_error( $tags_list ) ) {
				// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo '<span class="tags-links">' . $tags_list . '</span>';
			}
		}

		if ( is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link( esc_html__( 'Leave a comment', 'arcegator' ), esc_html__( '1 Comment', 'arcegator' ), esc_html__( '% Comments', 'arcegator' ) );
			echo '</span>';
		}

		if ( is_single() ){
			edit_post_link(
				sprintf(
					/* translators: %s: Name of current post */
					esc_html__( 'Edit %s', 'arcegator' ),
					the_title( '<span class="screen-reader-text">"', '"</span>', false )
				),
				'<span class="edit-link">',
				'</span>'
			);
		}
	}
}

if ( ! function_exists( 'arcegator_entry_meta' ) ) {
	/**
	 * Prints HTML with meta information for the categories.
	 */
	function arcegator_entry_meta() {
		if ( 'post' === get_post_type() ) {
			$categories_list = get_the_category_list( ' ' );
			if ( $categories_list ) {
				// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo '<div class="entry-meta"><span class="cat-links">' . $categories_list . '</span></div>';
			}
		}
	}
}

if ( ! function_exists( 'arcegator_the_custom_logo' ) ) {
	/**
	 * Displays the optional custom logo or Blog name / Description.
	 *
	 */
	function arcegator_the_custom_logo() {
		if ( function_exists( 'the_custom_logo' ) ) {
			$custom_logo_id = get_theme_mod( 'custom_logo' );
			$logo = wp_get_attachment_image_src( $custom_logo_id , 'full' );
			//var_dump($logo);
			if ( has_custom_logo() ) {
				echo '<h1 class="logo logo--link"><a href="'. esc_url( home_url( '/' ) ) . '" title="' . esc_html(get_bloginfo( 'name' )) . '"><img src="' . esc_url( $logo[0] ) . '" alt="' . esc_html(get_bloginfo( 'name' )) . '"></a></h1>';
			}else{
				echo '<h1 class="logo logo--text">
                    <a href="'. esc_url( home_url( '/' ) ) .'" title="Homepage">
                        <span class="site--name">'. esc_html(get_bloginfo( 'name' )) .'</span>
                        <span class="site--description">'. esc_html(get_bloginfo( 'description' )) .'</span>
                    </a>
                </h1>';
			}
		}
	}
}


if ( ! function_exists( 'arcegator_fixed_header' ) ) {
	/**
	 * Handle sticky header class.
	 *
	 */
	function arcegator_fixed_header(){
		if( get_theme_mod( 'arcegator_sticky_header' ) ){
			echo 'class="arcegator-sticky-header"';
		}
	}
}
